@@ -7,6 +7,25 @@ from .models import ProtectedModel
 
 
 class ProtectedModelMixinTestCase(TestCase):
+    def test_update_protected(self):
+        protected = ProtectedModel(name="protected", is_update_protected=True)
+        protected.save()
+        with self.assertRaises(PermissionDenied):
+            protected.save()
+
+    def test_update_unprotected(self):
+        unprotected = ProtectedModel(name="protected", is_update_protected=False)
+        unprotected.save()
+        unprotected.name = "changed"
+        unprotected.save()
+        self.assertEqual(unprotected.name, "changed")
+
+    def test_get_protected_against_update_message(self):
+        protected = ProtectedModel(name="protected", is_update_protected=True)
+        protected.save()
+        message = protected.get_update_protection_message()
+        self.assertEqual(message, "This object has update protection.")
+
     def test_delete_protected(self):
         protected = ProtectedModel(name="protected", is_delete_protected=True)
         protected.save()
